"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getServiceList = exports.getServiceActions = exports.getServiceInputs = exports.getServiceConfigDetail = exports.getServiceConfig = exports.getSubcommand = void 0;
function getSubcommand(configData) {
    var edition = configData.edition || '0.0.1';
    if (edition === '0.0.1') {
        return Object.keys(configData).filter(function (key) { return key !== 'Global'; });
    }
    else {
        var commands = configData.services || {};
        return Object.keys(commands);
    }
}
exports.getSubcommand = getSubcommand;
function getServiceConfig(configData, serviceName) {
    var edition = configData.edition || '0.0.1';
    if (edition === '0.0.1') {
        return configData[serviceName];
    }
    else {
        var serviceMap = configData.services || {};
        var serviceDetail = serviceMap[serviceName];
        var provider = serviceDetail.provider ? serviceDetail.provider : configData.provider;
        var access = serviceDetail.access ? serviceDetail.access : configData.access;
        var assembledServiceDetail = Object.assign({}, serviceDetail, { access: access, provider: provider });
        return assembledServiceDetail;
    }
}
exports.getServiceConfig = getServiceConfig;
function getServiceConfigDetail(configData) {
    var name = configData.Component || configData.component;
    var provider = configData.Provider || configData.provider;
    var access = configData.Access || configData.access;
    return { name: name, provider: provider, access: access };
}
exports.getServiceConfigDetail = getServiceConfigDetail;
function getServiceInputs(configData, version, options) {
    if (version === '0.0.1') {
        var Properties = configData.Properties, Params = configData.Params, Provider = configData.Provider, Access = configData.Access, Component = configData.Component, ProjectName = configData.ProjectName;
        var credentials = options.credentials, method = options.method;
        var inputs = {
            Properties: Properties,
            Credentials: credentials,
            Project: {
                ProjectName: ProjectName,
                Component: Component,
                Provider: Provider,
                AccessAlias: Access || '',
            },
            Command: method,
            Args: Params || '',
            Path: {
                ConfigPath: process.env.templateFile || '',
            },
        };
        return inputs;
    }
    else {
        var props = configData.props, params = configData.params, provider = configData.provider, access = configData.access, component = configData.component, ProjectName = configData.ProjectName, appName = configData.appName;
        var credentials = options.credentials, method = options.method;
        var inputs = {
            props: props,
            Properties: props,
            Credentials: credentials,
            credentials: credentials,
            appName: appName,
            Project: {
                ProjectName: ProjectName,
                projectName: ProjectName,
                component: component,
                Component: component,
                provider: provider,
                Provider: provider,
                accessAlias: access || '',
                AccessAlias: access || '',
            },
            command: method,
            Command: method,
            args: params || '',
            Args: params || '',
            path: {
                configPath: process.env.templateFile || '',
            },
            Path: {
                ConfigPath: process.env.templateFile || '',
            },
        };
        return inputs;
    }
}
exports.getServiceInputs = getServiceInputs;
function getServiceActions(configData, version, options) {
    var method = options.method;
    if (version === '0.0.1') {
        var _a = configData.Extends, Extends = _a === void 0 ? {} : _a;
        var hooks = Extends[method];
        return hooks;
    }
    else {
        var _b = configData.actions, actions_1 = _b === void 0 ? {} : _b;
        var hooks_1 = [];
        Object.keys(actions_1).forEach(function (actionKey) {
            var formatAction = actionKey.split('-');
            var hookList = actions_1[actionKey];
            if (formatAction.length > 1) {
                var _method = formatAction[1];
                if (_method === method) {
                    var _executionOrder_1 = formatAction[0];
                    hookList.forEach(function (hookDetail) {
                        var _hookDetail = {
                            Hook: hookDetail.run,
                            Path: hookDetail.path,
                            Pre: _executionOrder_1 === 'pre' ? true : false
                        };
                        hooks_1.push(_hookDetail);
                    });
                }
            }
            else if (actionKey === method) {
                hookList.forEach(function (hookDetail) {
                    var _hookDetail = {
                        Hook: hookDetail.run,
                        Path: hookDetail.path,
                        Pre: false
                    };
                    hooks_1.push(_hookDetail);
                });
            }
        });
        return hooks_1;
    }
}
exports.getServiceActions = getServiceActions;
function getServiceList(configData) {
    var edition = configData.edition || '0.0.1';
    if (edition === '0.0.1') {
        return configData;
    }
    else {
        return configData.services;
    }
}
exports.getServiceList = getServiceList;
//# sourceMappingURL=version.js.map